@@ -21,6 +21,7 @@ namespace eckit {
 
 class LockCmd : public CmdResource {
 public:
+
     // -- Contructors
 
     LockCmd();
@@ -30,6 +31,7 @@ public:
     ~LockCmd();
 
 private:
+
     // No copy allowed
 
     LockCmd(const LockCmd&);
@@ -39,10 +41,10 @@ private:
 
     // From CmdResource
 
-    virtual void execute(std::istream&, std::ostream&, CmdArg&) override;
+    void execute(std::istream&, std::ostream&, CmdArg&) override;
     virtual void man(std::ostream&) const;
-    virtual void help(std::ostream&) const override;
-    virtual Arg usage(const std::string& cmd) const override;
+    void help(std::ostream&) const override;
+    Arg usage(const std::string& cmd) const override;
 };
 
 inline void destroy(LockCmd**) {}
