@@ -50,8 +50,9 @@ struct PathExpanderRegistry {
         if (j == m.end()) {
             std::ostringstream msg;
             msg << "No PathExpander found with name '" << name << "'. Registered path expand handlers are:";
-            for (j = m.begin(); j != m.end(); ++j)
+            for (j = m.begin(); j != m.end(); ++j) {
                 msg << " '" << (*j).first << "'";
+            }
             throw eckit::UserError(msg.str());
         }
 
@@ -71,8 +72,9 @@ std::string PathExpander::expand(const std::string& path) {
     for (StringList::const_iterator it = vl.begin(); it != vl.end(); ++it) {
         const std::string& incurly = *it;
 
-        if (incurly.empty())
+        if (incurly.empty()) {
             throw BadValue("PathExpander received empty key");
+        }
 
         size_t pos      = incurly.find_first_of("?");
         std::string key = incurly.substr(0, pos);
@@ -89,8 +91,7 @@ std::string PathExpander::expand(const std::string& path) {
     return newpath;
 }
 
-PathExpander::PathExpander(const std::string& name) :
-    name_(name) {
+PathExpander::PathExpander(const std::string& name) : name_(name) {
     eckit::AutoLock<PathExpanderRegistry> locker(PathExpanderRegistry::instance());
 
     PathExpanderMap& m = PathExpanderRegistry::instance().map();
@@ -115,8 +116,8 @@ std::ostream& operator<<(std::ostream& s, const PathExpander& p) {
 
 class ENVVAR : public PathExpander {
 public:
-    ENVVAR(const std::string& name) :
-        PathExpander(name) {}
+
+    ENVVAR(const std::string& name) : PathExpander(name) {}
 
     virtual void expand(const std::string& var, const std::string& path, eckit::StringDict& vars) const {
         size_t pos      = var.find_first_of("?");
@@ -149,8 +150,8 @@ static ENVVAR envvar("ENVVAR");
 
 class FILE : public PathExpander {
 public:
-    FILE(const std::string& name) :
-        PathExpander(name) {}
+
+    FILE(const std::string& name) : PathExpander(name) {}
 
     virtual void expand(const std::string& var, const std::string& path, eckit::StringDict& vars) const {
         size_t pos      = var.find_first_of("?");
@@ -185,8 +186,8 @@ static FILE file("FILE");
 
 class CWDFS : public PathExpander {
 public:
-    CWDFS(const std::string& name) :
-        PathExpander(name) {}
+
+    CWDFS(const std::string& name) : PathExpander(name) {}
 
     virtual void expand(const std::string& var, const std::string& path, eckit::StringDict& vars) const {
         LocalPathName mnt = LocalPathName::cwd().mountPoint();
@@ -201,8 +202,8 @@ static CWDFS cwdfs("CWDFS");
 
 class CWD : public PathExpander {
 public:
-    CWD(const std::string& name) :
-        PathExpander(name) {}
+
+    CWD(const std::string& name) : PathExpander(name) {}
 
     virtual void expand(const std::string& var, const std::string& path, eckit::StringDict& vars) const {
         LocalPathName mnt = LocalPathName::cwd();
