@@ -41,8 +41,7 @@ static PathName tmp() {
 }
 
 
-TmpFile::TmpFile(bool verbose) :
-    PathName(tmp()), verbose_(verbose) {}
+TmpFile::TmpFile(bool verbose) : PathName(tmp()), verbose_(verbose) {}
 
 TmpFile::~TmpFile() {
     unlink(verbose_);
