@@ -14,6 +14,7 @@
 
 #include <utility>
 
+#include "eckit/geo/PointLonLat.h"
 #include "eckit/geo/range/Regular.h"
 
 
@@ -22,12 +23,11 @@ namespace eckit::geo::range {
 
 class RegularLongitude final : public Regular {
 public:
+
     // -- Constructors
 
-    explicit RegularLongitude(double inc, double a, double b, double ref, double eps = 0.);
-    explicit RegularLongitude(double inc, double a, double b, double eps = 0.) : RegularLongitude(inc, a, b, a, eps) {}
-
-    explicit RegularLongitude(size_t n, double a, double b, double eps = 0.);
+    explicit RegularLongitude(double inc, double a, double b, double ref);
+    explicit RegularLongitude(size_t n, double a, double b);
 
     // -- Overridden methods
 
@@ -37,10 +37,11 @@ public:
     bool periodic() const override { return getPeriodic(); }
 
 private:
+
     // -- Constructors
 
-    RegularLongitude(size_t n, double a, double b, std::vector<double>&& values, bool periodic, double eps) :
-        Regular(n, a, b, std::move(values), periodic, eps) {}
+    RegularLongitude(size_t n, double a, double b, std::vector<double>&& values, bool periodic) :
+        Regular(n, a, b, std::move(values), periodic, PointLonLat::EPS) {}
 };
 
 
