@@ -20,19 +20,16 @@
 
 //------------------------------------------------------------------------------------------------------
 
-namespace eckit {
-namespace geometry {
+namespace eckit::geometry {
 
 //------------------------------------------------------------------------------------------------------
 
-enum XYZCOORDS
-{
+enum XYZCOORDS {
     XX = 0,
     YY = 1,
     ZZ = 2
 };
-enum LLCOORDS
-{
+enum LLCOORDS {
     LON = XX,
     LAT = YY
 };
@@ -42,9 +39,11 @@ enum LLCOORDS
 template <int SIZE = 2>
 class KPoint {
 protected:
+
     double x_[SIZE] = {0};
 
 public:
+
     static const size_t DIMS = SIZE;
 
     double x(size_t axis) const { return x_[axis]; }
@@ -107,8 +106,9 @@ public:
 
     static bool equal(const KPoint& p1, const KPoint& p2) {
         for (size_t i = 0; i < dimensions(); i++) {
-            if (p1.x_[i] != p2.x_[i])
+            if (p1.x_[i] != p2.x_[i]) {
                 return false;
+            }
         }
         return true;
     }
@@ -280,7 +280,6 @@ const size_t KPoint<SIZE>::DIMS;
 
 //------------------------------------------------------------------------------------------------------
 
-}  // namespace geometry
-}  // namespace eckit
+}  // namespace eckit::geometry
 
 #endif
