@@ -15,8 +15,7 @@
 
 //------------------------------------------------------------------------------------------------------
 
-namespace eckit {
-namespace geometry {
+namespace eckit::geometry {
 
 //------------------------------------------------------------------------------------------------------
 
@@ -39,7 +38,6 @@ typedef SphereT<DatumUnit> UnitSphere;
 
 //------------------------------------------------------------------------------------------------------
 
-}  // namespace geometry
-}  // namespace eckit
+}  // namespace eckit::geometry
 
 #endif
