@@ -11,7 +11,8 @@
 #ifndef eckit_io_ResizableBuffer_h
 #define eckit_io_ResizableBuffer_h
 
-#warning "Header eckit/io/ResizableBuffer.h and class eckit::ResizableBuffer is deprecated -- include eckit/io/Buffer.h and use eckit::Buffer"
+#warning \
+    "Header eckit/io/ResizableBuffer.h and class eckit::ResizableBuffer is deprecated -- include eckit/io/Buffer.h and use eckit::Buffer"
 #include "eckit/io/Buffer.h"
 
 namespace eckit {
