@@ -14,6 +14,7 @@
 #include <cstddef>
 #include <iterator>
 #include <string>
+#include <string_view>
 #include <vector>
 
 #include "eckit/filesystem/PathName.h"
@@ -35,25 +36,25 @@ class Environment;
 
 /// @returns the communicator registered with associated name, or default communicator when NULL is
 /// passed
-Comm& comm(const char* name = nullptr);
+Comm& comm(std::string_view name = {});
 
 Comm& self();
 
 /// Set a communicator as default
-void setCommDefault(const char* name);
+void setCommDefault(std::string_view name);
 
 /// Register a communicator comming from Fortran code
-void addComm(const char* name, int comm);
+void addComm(std::string_view name, int comm);
 
 /// Register an existing communicator
-void addComm(const char* name, Comm* comm);
+void addComm(std::string_view name, Comm* comm);
 
 /// Unregister and delete specific comm
 /// @pre Comm is registered in the environment
-void deleteComm(const char* name);
+void deleteComm(std::string_view name);
 
 /// Check if a communicator is registered
-bool hasComm(const char* name);
+bool hasComm(std::string_view name);
 
 std::vector<std::string> listComms();
 
@@ -78,9 +79,11 @@ class Comm : private eckit::NonCopyable {
     friend class Environment;
 
 public:  // class methods
-    static Comm& comm(const char* name = nullptr);
+
+    static Comm& comm(std::string_view name = {});
 
 public:  // methods
+
     std::string name() const { return name_; }
 
     /// @brief Returns name of processor according to MPI
@@ -367,12 +370,10 @@ public:  // methods
     ///
 
     template <typename T>
-    Status sendReceiveReplace(T* sendrecv, size_t count,
-                              int dest, int sendtag, int source, int recvtag) const;
+    Status sendReceiveReplace(T* sendrecv, size_t count, int dest, int sendtag, int source, int recvtag) const;
 
     template <typename T>
-    Status sendReceiveReplace(T& sendrecv,
-                              int dest, int sendtag, int source, int recvtag) const;
+    Status sendReceiveReplace(T& sendrecv, int dest, int sendtag, int source, int recvtag) const;
 
     ///
     /// All to all of vector< vector<> >
@@ -394,57 +395,45 @@ public:  // methods
     virtual int communicator() const = 0;
 
 protected:  // methods
+
     virtual size_t getCount(Status& status, Data::Code datatype) const = 0;
 
     virtual void broadcast(void* buffer, size_t count, Data::Code datatype, size_t root) const = 0;
 
     virtual void gather(const void* sendbuf, size_t sendcount, void* recvbuf, size_t recvcount, Data::Code datatype,
-                        size_t root) const
-        = 0;
+                        size_t root) const = 0;
 
     virtual void scatter(const void* sendbuf, size_t sendcount, void* recvbuf, size_t recvcount, Data::Code datatype,
-                         size_t root) const
-        = 0;
+                         size_t root) const = 0;
 
     virtual void gatherv(const void* sendbuf, size_t sendcount, void* recvbuf, const int recvcounts[],
-                         const int displs[], Data::Code datatype, size_t root) const
-        = 0;
+                         const int displs[], Data::Code datatype, size_t root) const = 0;
 
     virtual void scatterv(const void* sendbuf, const int sendcounts[], const int displs[], void* recvbuf,
-                          size_t recvcount, Data::Code datatype, size_t root) const
-        = 0;
+                          size_t recvcount, Data::Code datatype, size_t root) const = 0;
 
-    virtual void reduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code datatype,
-                        Operation::Code op, size_t root) const
-        = 0;
+    virtual void reduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code datatype, Operation::Code op,
+                        size_t root) const = 0;
 
-    virtual void reduceInPlace(void* sendrecvbuf, size_t count, Data::Code datatype,
-                               Operation::Code op, size_t root) const
-        = 0;
+    virtual void reduceInPlace(void* sendrecvbuf, size_t count, Data::Code datatype, Operation::Code op,
+                               size_t root) const = 0;
 
     virtual void allReduce(const void* sendbuf, void* recvbuf, size_t count, Data::Code datatype,
-                           Operation::Code op) const
-        = 0;
+                           Operation::Code op) const = 0;
 
-    virtual void allReduceInPlace(void* sendrecvbuf, size_t count, Data::Code datatype,
-                                  Operation::Code op) const
-        = 0;
+    virtual void allReduceInPlace(void* sendrecvbuf, size_t count, Data::Code datatype, Operation::Code op) const = 0;
 
     virtual void allGather(const void* sendbuf, size_t sendcount, void* recvbuf, size_t recvcount,
-                           Data::Code datatype) const
-        = 0;
+                           Data::Code datatype) const = 0;
 
     virtual void allGatherv(const void* sendbuf, size_t sendcount, void* recvbuf, const int recvcounts[],
-                            const int displs[], Data::Code datatype) const
-        = 0;
+                            const int displs[], Data::Code datatype) const = 0;
 
     virtual void allToAll(const void* sendbuf, size_t sendcount, void* recvbuf, size_t recvcount,
-                          Data::Code datatype) const
-        = 0;
+                          Data::Code datatype) const = 0;
 
     virtual void allToAllv(const void* sendbuf, const int sendcounts[], const int sdispls[], void* recvbuf,
-                           const int recvcounts[], const int rdispls[], Data::Code datatype) const
-        = 0;
+                           const int recvcounts[], const int rdispls[], Data::Code datatype) const = 0;
 
     virtual Status receive(void* recv, size_t count, Data::Code datatype, int source, int tag) const = 0;
 
@@ -456,9 +445,8 @@ protected:  // methods
 
     virtual Request iSend(const void* send, size_t count, Data::Code datatype, int dest, int tag) const = 0;
 
-    virtual Status sendReceiveReplace(void* sendrecv, size_t count, Data::Code datatype,
-                                      int dest, int sendtag, int source, int recvtag) const
-        = 0;
+    virtual Status sendReceiveReplace(void* sendrecv, size_t count, Data::Code datatype, int dest, int sendtag,
+                                      int source, int recvtag) const = 0;
 
     /// @brief Call free on this communicator
     /// After calling this method, the communicator should not be used again
@@ -469,6 +457,7 @@ protected:  // methods
     virtual eckit::mpi::Comm* self() const = 0;
 
 private:  // methods
+
     virtual void print(std::ostream&) const = 0;
 
     friend std::ostream& operator<<(std::ostream& s, const Comm& o) {
@@ -477,7 +466,8 @@ private:  // methods
     }
 
 protected:  // methods
-    Comm(const std::string& name);
+
+    Comm(std::string_view name);
 
     virtual ~Comm();
 
@@ -492,25 +482,26 @@ class CommFactory {
     friend class eckit::mpi::Environment;
 
     std::string builder_;
-    virtual Comm* make(const std::string& name)      = 0;
-    virtual Comm* make(const std::string& name, int) = 0;
+    virtual Comm* make(std::string_view name)      = 0;
+    virtual Comm* make(std::string_view name, int) = 0;
 
 protected:
-    CommFactory(const std::string& builder);
+
+    CommFactory(std::string_view builder);
     virtual ~CommFactory();
 
-    static Comm* build(const std::string& name, const std::string& builder);
-    static Comm* build(const std::string& name, const std::string& builder, int);
+    static Comm* build(std::string_view name, std::string_view builder);
+    static Comm* build(std::string_view name, std::string_view builder, int);
 };
 
 template <class T>
 class CommBuilder : public CommFactory {
-    Comm* make(const std::string& name) override { return new T(name); }
-    Comm* make(const std::string& name, int comm) override { return new T(name, comm); }
+    Comm* make(std::string_view name) override { return new T(name); }
+    Comm* make(std::string_view name, int comm) override { return new T(name, comm); }
 
 public:
-    CommBuilder(const std::string& builder) :
-        CommFactory(builder) {}
+
+    CommBuilder(const std::string& builder) : CommFactory(builder) {}
 };
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -519,7 +510,15 @@ public:
 
 //----------------------------------------------------------------------------------------------------------------------
 
+#if defined(__clang_analyzer__)
+// By adding C assert, the analyzer can make assumptions on conditions, preventing false positive warnings
+#include <cassert>
+#define ECKIT_MPI_ASSERT(a)                                             \
+    eckit::mpi::detail::Assert(!(a), #a, __FILE__, __LINE__, __func__); \
+    assert(a)
+#else
 #define ECKIT_MPI_ASSERT(a) eckit::mpi::detail::Assert(!(a), #a, __FILE__, __LINE__, __func__)
+#endif
 
 template <typename T>
 size_t eckit::mpi::Comm::getCount(Status& status) const {
@@ -570,7 +569,7 @@ void eckit::mpi::Comm::broadcast(Iter first, Iter last, size_t root) const {
     ECKIT_MPI_ASSERT(root < commsize);
 
     typename std::iterator_traits<Iter>::difference_type n = std::distance(first, last);
-    Data::Code type                                        = Data::Type<typename std::iterator_traits<Iter>::value_type>::code();
+    Data::Code type = Data::Type<typename std::iterator_traits<Iter>::value_type>::code();
 
     broadcast(&(*first), n, type, root);
 }
@@ -584,6 +583,7 @@ void eckit::mpi::Comm::gather(CIter first, CIter last, Iter rfirst, Iter rlast,
     typedef typename std::iterator_traits<CIter>::difference_type diff_t;
 
     const size_t commsize = size();
+    ECKIT_MPI_ASSERT(commsize > 0);
     ECKIT_MPI_ASSERT(root < commsize);
 
     const diff_t sendcount = std::distance(first, last);
@@ -606,6 +606,7 @@ void eckit::mpi::Comm::gather(CIter first, CIter last, Iter rfirst, Iter rlast,
 template <typename T>
 void eckit::mpi::Comm::gather(const T send, std::vector<T>& recv, size_t root) const {
     size_t commsize = size();
+    ECKIT_MPI_ASSERT(commsize > 0);
     ECKIT_MPI_ASSERT(root < commsize);
     ECKIT_MPI_ASSERT(recv.size() % commsize == 0); /* receiving size is multiple of comm().size() */
     size_t recvcount = recv.size() / commsize;
@@ -618,6 +619,7 @@ void eckit::mpi::Comm::gather(const T send, std::vector<T>& recv, size_t root) c
 template <typename T>
 void eckit::mpi::Comm::gather(const std::vector<T>& send, std::vector<T>& recv, size_t root) const {
     size_t commsize = size();
+    ECKIT_MPI_ASSERT(commsize > 0);
     ECKIT_MPI_ASSERT(root < commsize);
     ECKIT_MPI_ASSERT(recv.size() % commsize == 0); /* receiving size is multiple of comm().size() */
     size_t recvcount = recv.size() / commsize;
@@ -687,6 +689,7 @@ void eckit::mpi::Comm::gatherv(const std::vector<T>& send, std::vector<T>& recv,
 template <typename T>
 void eckit::mpi::Comm::scatter(const std::vector<T>& send, T& recv, size_t root) const {
     size_t commsize = size();
+    ECKIT_MPI_ASSERT(commsize > 0);
     ECKIT_MPI_ASSERT(root < commsize);
     ECKIT_MPI_ASSERT(send.size() % commsize == 0);
     size_t sendcount = send.size() / commsize;
@@ -699,6 +702,7 @@ void eckit::mpi::Comm::scatter(const std::vector<T>& send, T& recv, size_t root)
 template <typename T>
 void eckit::mpi::Comm::scatter(const std::vector<T>& send, std::vector<T>& recv, size_t root) const {
     size_t commsize = size();
+    ECKIT_MPI_ASSERT(commsize > 0);
     ECKIT_MPI_ASSERT(root < commsize);
     ECKIT_MPI_ASSERT(send.size() % commsize == 0);
     size_t sendcount = send.size() / commsize;
@@ -789,7 +793,7 @@ void eckit::mpi::Comm::reduceInPlace(T& sendrecvbuf, Operation::Code op, size_t
 template <class Iter>
 void eckit::mpi::Comm::reduceInPlace(Iter first, Iter last, Operation::Code op, size_t root) const {
     typename std::iterator_traits<Iter>::difference_type count = std::distance(first, last);
-    Data::Code type                                            = Data::Type<typename std::iterator_traits<Iter>::value_type>::code();
+    Data::Code type = Data::Type<typename std::iterator_traits<Iter>::value_type>::code();
     reduceInPlace(&(*first), count, type, op, root);
 }
 
@@ -830,7 +834,7 @@ void eckit::mpi::Comm::allReduceInPlace(T& sendrecvbuf, Operation::Code op) cons
 template <class Iter>
 void eckit::mpi::Comm::allReduceInPlace(Iter first, Iter last, Operation::Code op) const {
     typename std::iterator_traits<Iter>::difference_type count = std::distance(first, last);
-    Data::Code type                                            = Data::Type<typename std::iterator_traits<Iter>::value_type>::code();
+    Data::Code type = Data::Type<typename std::iterator_traits<Iter>::value_type>::code();
     allReduceInPlace(&(*first), count, type, op);
 }
 
@@ -882,6 +886,7 @@ void eckit::mpi::Comm::allGatherv(CIter first, CIter last, Iter rfirst, const in
 template <typename T>
 void eckit::mpi::Comm::allToAll(const std::vector<T>& send, std::vector<T>& recv) const {
     size_t commsize = size();
+    ECKIT_MPI_ASSERT(commsize > 0);
     ECKIT_MPI_ASSERT(send.size() % commsize == 0);
     ECKIT_MPI_ASSERT(recv.size() % commsize == 0);
 
@@ -958,17 +963,15 @@ void eckit::mpi::Comm::synchronisedSend(const T& sendbuf, int dest, int tag) con
 ///
 
 template <typename T>
-eckit::mpi::Status eckit::mpi::Comm::sendReceiveReplace(T* sendrecv, size_t count,
-                                                        int dest, int sendtag, int source, int recvtag) const {
-    return sendReceiveReplace(sendrecv, count, Data::Type<T>::code(),
-                              dest, sendtag, source, recvtag);
+eckit::mpi::Status eckit::mpi::Comm::sendReceiveReplace(T* sendrecv, size_t count, int dest, int sendtag, int source,
+                                                        int recvtag) const {
+    return sendReceiveReplace(sendrecv, count, Data::Type<T>::code(), dest, sendtag, source, recvtag);
 }
 
 template <typename T>
-eckit::mpi::Status eckit::mpi::Comm::sendReceiveReplace(T& sendrecv,
-                                                        int dest, int sendtag, int source, int recvtag) const {
-    return sendReceiveReplace(&sendrecv, 1, Data::Type<T>::code(),
-                              dest, sendtag, source, recvtag);
+eckit::mpi::Status eckit::mpi::Comm::sendReceiveReplace(T& sendrecv, int dest, int sendtag, int source,
+                                                        int recvtag) const {
+    return sendReceiveReplace(&sendrecv, 1, Data::Type<T>::code(), dest, sendtag, source, recvtag);
 }
 
 ///
