@@ -8,23 +8,24 @@
  * does it submit to any jurisdiction.
  */
 
-#include "eckit/mpi/ParallelRequest.h"
+#include <string_view>
+
 #include "eckit/log/CodeLocation.h"
 #include "eckit/mpi/Parallel.h"
+#include "eckit/mpi/ParallelRequest.h"
 
 namespace eckit {
 namespace mpi {
 
 
-void MPICall(int code, const char* mpifunc, const eckit::CodeLocation& loc);
+void MPICall(int code, std::string_view mpifunc, const eckit::CodeLocation& loc);
 #define MPI_CALL(a) MPICall(a, #a, Here())
 
 //----------------------------------------------------------------------------------------------------------------------
 
 ParallelRequest::ParallelRequest() {}
 
-ParallelRequest::ParallelRequest(MPI_Request request) :
-    request_(request) {}
+ParallelRequest::ParallelRequest(MPI_Request request) : request_(request) {}
 
 void ParallelRequest::print(std::ostream& os) const {
     os << "ParallelRequest("
