@@ -13,10 +13,7 @@
 #include "eckit/config/Resource.h"
 #include "eckit/net/Endpoint.h"
 
-
-namespace eckit {
-namespace net {
-
+namespace eckit::net {
 
 TCPClient::TCPClient(const SocketOptions& options) : TCPSocket(), port_(0), options_(options) {}
 TCPClient::TCPClient(int port, const SocketOptions& options) : TCPSocket(), port_(port), options_(options) {}
@@ -37,9 +34,8 @@ void TCPClient::print(std::ostream& s) const {
 }
 
 /// @note TCPClient::connect(host, port, retries, timeout) is found in TCPSocket.cc
-TCPSocket& TCPClient::connect(const net::Endpoint& endpoint, int retries, int timeout) {
-    return connect(endpoint.hostname(), endpoint.port(), retries, timeout);
+TCPSocket& TCPClient::connect(const net::Endpoint& endpoint, int retries, int timeout, int retryDelay) {
+    return connect(endpoint.hostname(), endpoint.port(), retries, timeout, retryDelay);
 }
 
-}  // namespace net
-}  // namespace eckit
+}  // namespace eckit::net
