@@ -71,8 +71,7 @@ void _export(eckit::Exporter& out, double what) {
 
 const int MAX_STRING_LEN = 10240;
 
-enum
-{
+enum {
 
     TAG_EOF = 'X',
 
@@ -96,7 +95,6 @@ enum
 
     TAG_START_DATABASE = '[',
     TAG_END_DATABASE   = ']'
-
 };
 
 template <class T>
@@ -123,6 +121,7 @@ const int Swap<T>::last = sizeof(T) - 1;
 
 class Endian {
 public:
+
 #if eckit_LITTLE_ENDIAN
     template <class T>
     static T transform(T x) {
@@ -528,11 +527,9 @@ unsigned long long Exporter::getUnsignedMember(const std::string& name) {
     return 0;
 }
 
-Evolve::Evolve(eckit::Exporter& e) :
-    e_(e), parent_(nullptr) {}
+Evolve::Evolve(eckit::Exporter& e) : e_(e), parent_(nullptr) {}
 
-Evolve::Evolve(Evolve* e, char const* klass, char const* name) :
-    e_(e->e_), path_(e->path()), parent_(e) {
+Evolve::Evolve(Evolve* e, char const* klass, char const* name) : e_(e->e_), path_(e->path()), parent_(e) {
     if (path_.length()) {
         path_ += ".";
     }
@@ -589,14 +586,11 @@ Evolve::operator long() {
     return e_.getSignedMember(path_);
 }
 
-Exporter::Datatype::Datatype() :
-    type_(0), used_(false), double_(0), signed_(0), unsigned_(0) {}
+Exporter::Datatype::Datatype() : type_(0), used_(false), double_(0), signed_(0), unsigned_(0) {}
 
-Exporter::Datatype::Datatype(double d) :
-    type_(TAG_DOUBLE), used_(false), double_(d), signed_(0), unsigned_(0) {}
+Exporter::Datatype::Datatype(double d) : type_(TAG_DOUBLE), used_(false), double_(d), signed_(0), unsigned_(0) {}
 
-Exporter::Datatype::Datatype(long long d) :
-    type_(TAG_SIGNED), used_(false), double_(0), signed_(d), unsigned_(0) {}
+Exporter::Datatype::Datatype(long long d) : type_(TAG_SIGNED), used_(false), double_(0), signed_(d), unsigned_(0) {}
 
 Exporter::Datatype::Datatype(unsigned long long d) :
     type_(TAG_UNSIGNED), used_(false), double_(0), signed_(0), unsigned_(d) {}
