@@ -16,8 +16,7 @@
 #include "eckit/sql/SQLTable.h"
 #include "eckit/sql/SelectOneTable.h"
 
-namespace eckit {
-namespace sql {
+namespace eckit::sql {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -39,7 +38,6 @@ struct Environment {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace sql
-}  // namespace eckit
+}  // namespace eckit::sql
 
 #endif
