@@ -12,13 +12,11 @@
 #include "eckit/sql/SQLSelect.h"
 #include "eckit/sql/expression/SQLExpressions.h"
 
-namespace eckit {
-namespace sql {
+namespace eckit::sql {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-SQLDistinctOutput::SQLDistinctOutput(SQLOutput& output) :
-    output_(output) {}
+SQLDistinctOutput::SQLDistinctOutput(SQLOutput& output) : output_(output) {}
 
 SQLDistinctOutput::~SQLDistinctOutput() {}
 
@@ -120,5 +118,4 @@ void SQLDistinctOutput::outputBitfield(double, bool) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace sql
-}  // namespace eckit
+}  // namespace eckit::sql
